Functions to work with appropriate cloudstack payloads.
Functions to work with appropriate cloudstack payloads.
(build-payload config params)(build-payload config opcode params)Build a signed payload for a given config, opcode and args triplet
Build a signed payload for a given config, opcode and args triplet
(query-args params)Build arguments, ready to be signed.
Build arguments, ready to be signed.
(quote-plus s)Replace + in encoded URL by %20
Replace + in encoded URL by %20
(serialize-pair [k v])Encode a key/value pair
Encode a key/value pair
(transform-arg [k v])Transform argument into a list of key/value pairs.
Transform argument into a list of key/value pairs.
(transform-maps param maps)For a list of maps, produce the expected key/value pairs.
For a list of maps, produce the expected key/value pairs.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |